# pypldl

pypldl is an HTTP fetcher with parallel downloading.
It uses a plugin system to handle different kinds of URLs.


## Install

  pip install pypldl

## Usage

Three interfaces are available:

* a CLI script: `pypldl`
* a GUI script: `pypldl-gui`
* the Python module, for advanced usage and manual scripting

